pub struct AuthorizationCode(pub String);Expand description
Authorization code
Is used for obtaining the the access and refresh tokens. It’s purpose is to be immediately exchanged for an access_token and refresh_token.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for AuthorizationCode
impl Clone for AuthorizationCode
Sourcefn clone(&self) -> AuthorizationCode
fn clone(&self) -> AuthorizationCode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthorizationCode
impl Debug for AuthorizationCode
Sourceimpl<'de> Deserialize<'de> for AuthorizationCode
impl<'de> Deserialize<'de> for AuthorizationCode
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for AuthorizationCode
impl Display for AuthorizationCode
impl Eq for AuthorizationCode
Sourceimpl PartialEq for AuthorizationCode
impl PartialEq for AuthorizationCode
Sourceimpl Serialize for AuthorizationCode
impl Serialize for AuthorizationCode
impl StructuralPartialEq for AuthorizationCode