pub struct PINCode(pub String);Expand description
PIN code
Is also used for obtaining the the access and refresh tokens, but it’s presented to the user so that they can enter it directly into your app. It’s purpose is to be immediately exchanged for an access_token and refresh_token.
Tuple Fields
0: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for PINCode
impl<'de> Deserialize<'de> for PINCode
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PINCode
impl StructuralPartialEq for PINCode